@@ -1,13 +1,14 @@
 import typing
 from typing import Iterable
-
 from typedpy.structures import REQUIRED_FIELDS, StructMeta, Structure, _init_class_dict
 
+T = typing.TypeVar("T")
+
 
 class PartialMeta(type):
     def __getitem__(
-        cls, clazz: typing.Union[StructMeta, typing.Tuple[StructMeta, str]]
-    ):
+        cls: T, clazz: typing.Union[StructMeta, typing.Tuple[StructMeta, str]]
+    ) -> T:
         if not isinstance(clazz, StructMeta):
             if not isinstance(clazz, tuple) or (
                 isinstance(clazz, tuple)
@@ -30,9 +31,9 @@ class PartialMeta(type):
 
         cls_dict[REQUIRED_FIELDS] = []
 
-        newclass = type(classname, (Structure,), cls_dict)
+        new_class = type(classname, (Structure,), cls_dict)
 
-        return newclass
+        return new_class
 
 
 class Partial(metaclass=PartialMeta):
@@ -52,7 +53,7 @@ class Partial(metaclass=PartialMeta):
             x: str
 
     "Bar" has all the fields of Foo as optional, and in addition "x" as required. Note that Bar does not extend Foo, but
-    it is a Structure class. It does copy attributes like serialization mappers, _ignore_none,
+    it is a Structure class. It does not copy the serialization mappers. It does copy other attributes, such as _ignore_none,
     but Bar can override any of them.
 
     Another valid usage:
@@ -125,8 +126,9 @@ class AllFieldsRequired(metaclass=AllFieldsRequiredMeta):
 
     "Bar" has all the fields of Foo as required with the exception of "d" (since it has a default value), and in
      addition "x" as required.
-     Note that Bar does not extend Foo, but it is a Structure class. It does copy attributes like serialization
-      mappers, _ignore_none, but Bar can override any of them.
+     Note that Bar does not extend Foo, but it is a Structure class. It does not copy the serialization mappers. 
+     It does copy other attributes, such as _ignore_none,
+     but Bar can override any of them.
 
     Another valid usage:
 
@@ -192,8 +194,8 @@ class Extend(metaclass=ExtendMeta):
     "Bar" has all the fields of Foo, and in addition "x". So the required fields in this case are i, s, a, x
     (since d has a default value).
     Note that Bar does not extend Foo, but it is a Structure class.
-    It does copy attributes like serialization mappers, _ignore_none, but Bar can override
-    any of them.
+    It does not copy the serialization mappers. It does copy other attributes, such as _ignore_none,
+    but Bar can override any of them.
 
     Another valid usage:
 
@@ -250,7 +252,7 @@ class Omit(metaclass=OmitMeta):
             x: int
 
     "Bar" has the fields: i, d, s, x. Note that Bar does not extend Foo, but it is a Structure class.
-     It does copy attributes like serialization mappers, _ignore_none,
+    It does not copy the serialization mappers. It does copy other attributes, such as _ignore_none,
     but Bar can override any of them.
 
     Another valid usage:
@@ -305,7 +307,7 @@ class Pick(metaclass=PickMeta):
             x: int
 
     "Bar" has the fields: a, b, x. Note that Bar does not extend Foo, but it is a Structure class.
-     It does copy attributes like serialization mappers, _ignore_none,
+     It does not copy the serialization mappers. It does copy other attributes, such as _ignore_none,
     but Bar can override any of them.
 
     Another valid usage:
